pub fn is_cache_valid<P: AsRef<Path>>(
source_path: P,
config: &BinaryConfig,
) -> boolExpand description
Check if binary cache exists and is newer than source
pub fn is_cache_valid<P: AsRef<Path>>(
source_path: P,
config: &BinaryConfig,
) -> boolCheck if binary cache exists and is newer than source