pub struct CacheGenerator { /* private fields */ }Expand description
Cache generator for DX documents
Implementations
Sourceimpl CacheGenerator
impl CacheGenerator
Sourcepub fn with_config(config: CacheConfig) -> Self
pub fn with_config(config: CacheConfig) -> Self
Create a cache generator with custom config
Sourcepub fn map_path_to_cache(
&self,
source_path: &Path,
base_path: &Path,
) -> CachePaths
pub fn map_path_to_cache( &self, source_path: &Path, base_path: &Path, ) -> CachePaths
Map a source path to cache paths
Preserves the relative path structure in the cache directory.
Example: src/config/data.dx -> .dx/cache/llm/src/config/data.dx.llm
Sourcepub fn generate(
&self,
source_path: &Path,
base_path: &Path,
) -> Result<CacheResult, CacheError>
pub fn generate( &self, source_path: &Path, base_path: &Path, ) -> Result<CacheResult, CacheError>
Generate cache files from a Human format source file
Sourcepub fn generate_from_document(
&self,
doc: &DxDocument,
source_path: &Path,
base_path: &Path,
) -> Result<CacheResult, CacheError>
pub fn generate_from_document( &self, doc: &DxDocument, source_path: &Path, base_path: &Path, ) -> Result<CacheResult, CacheError>
Generate cache files from a DxDocument
Sourcepub fn config(&self) -> &CacheConfig
pub fn config(&self) -> &CacheConfig
Get the config