pub enum SerializerOutputError {
Io(Error),
Parse(String),
Convert(ConvertError),
InvalidPath(String),
InvalidMetadata(String),
DirectoryCreation(String),
}Expand description
Serializer output errors
Variants
Io(Error)
Filesystem read or write failed.
Parse(String)
Human or LLM format parsing failed.
Convert(ConvertError)
Conversion between serializer formats failed.
InvalidPath(String)
Source or output path was not valid for serializer output.
InvalidMetadata(String)
Machine metadata did not match the current source or machine bytes.
DirectoryCreation(String)
Output directory could not be created.