Table Wrapper for Wide Tables
Provides functionality to wrap wide tables that exceed the maximum line width. When a table row is too wide, it splits the row into multiple display lines while maintaining column alignment.
Example
A wide table row like:
│ id │ name │ very_long_description_that_exceeds_width │ status │Gets wrapped to:
│ id │ name │ very_long_description... │ status │
│ │ │ ...that_exceeds_width │ │Structs
- Table
Wrapper - Table wrapper for handling wide tables
- Table
Wrapper Config - Configuration for table wrapping