pub enum MachineCacheError {
Show 18 variants
Io(Error),
InvalidCachePath(String),
InvalidCacheName(String),
UnsupportedCodec(MachineCacheCodec),
UnsupportedCodecId(u32),
Serialization(String),
InvalidMagic,
UnsupportedVersion(u32),
InvalidHeaderLength(u32),
ReservedBytesSet,
LengthMismatch,
SourceMismatch,
SchemaMismatch,
PayloadChecksumMismatch,
ArchiveChecksumMismatch,
BytecheckFailed(String),
Json(String),
Toml(String),
}Expand description
Error returned by typed machine cache helpers.
Variants
Io(Error)
Underlying I/O operation failed.
InvalidCachePath(String)
Source path or cache path is not valid for a project cache.
InvalidCacheName(String)
Project name or cache name contains unsupported characters.
UnsupportedCodec(MachineCacheCodec)
Requested codec is not supported by the typed cache helper yet.
UnsupportedCodecId(u32)
Cache bytes specified an unknown codec ID.
Serialization(String)
RKYV serialization failed.
InvalidMagic
Header magic did not match typed machine cache bytes.
UnsupportedVersion(u32)
Header version is not supported.
InvalidHeaderLength(u32)
Header length was not the expected fixed size.
ReservedBytesSet
Header reserved bytes or flags were non-zero.
LengthMismatch
Payload length in the header did not match file bytes.
SourceMismatch
Source fingerprint did not match the authoritative source file.
SchemaMismatch
Schema identity did not match the expected typed payload.
PayloadChecksumMismatch
Payload checksum did not match.
ArchiveChecksumMismatch
Archive checksum did not match.
BytecheckFailed(String)
RKYV byte validation failed.
Json(String)
JSON source parsing failed.
Toml(String)
TOML source parsing failed.