pub enum MachineCacheMiss {
Missing(PathBuf),
Invalid(MachineCacheError),
}Expand description
Reason a typed cache could not be opened as a valid fast-path hit.
Variants
Missing(PathBuf)
Machine cache file does not exist.
Invalid(MachineCacheError)
Machine cache existed but was invalid, stale, or unreadable.