pub fn source_fingerprint(
path: &Path,
) -> Result<MachineCacheSource, MachineCacheError>Expand description
Compute the authoritative source fingerprint for a cache input file.
pub fn source_fingerprint(
path: &Path,
) -> Result<MachineCacheSource, MachineCacheError>Compute the authoritative source fingerprint for a cache input file.