pub struct MachineCacheSource {
pub path: PathBuf,
pub bytes: u64,
pub modified_unix_ms: Option<u64>,
pub blake3: [u8; 32],
}Expand description
Fingerprint for the authoritative source file behind a machine cache.
Fields
path: PathBufSource file path.
bytes: u64Source file length in bytes.
modified_unix_ms: Option<u64>Source modified time as Unix milliseconds, when the platform provides it.
blake3: [u8; 32]BLAKE3 hash of the source file bytes.