Token

Enum Token 

pub enum Token<'a> {
Show 20 variants Eof, Newline, Colon, Equals, Caret, Pipe, Stream, Ditto, Null, True, False, Bang, Void, Dollar, At, Percent, Dot, Ident(&'a [u8]), Int(i64), Float(f64),
}
Token types in DX format

Variants



Eof

End of input



Newline

Newline



Colon

Colon (:)



Equals

Equals (=) - Schema definition



Caret

Caret (^) - Prefix inheritance



Pipe

Pipe (|) - Array delimiter



Stream

Greater than (>) - Stream operator



Ditto

Underscore (_) - Ditto



Null

Tilde (~) - Null



True

Plus (+) - True



False

Minus (-) - False



Bang

Bang (!) - Implicit true flag



Void

Question (?) - Implicit null



Dollar

Dollar ($) - Alias definition



At

At (@) - Anchor reference



Percent

Percent (%) - Type hint



Dot

Dot (.) - Path separator



Ident(&'a [u8])

Identifier/String



Int(i64)

Integer



Float(f64)

Float