pub struct Tokenizer<'a> { /* private fields */ }Expand description
Zero-copy tokenizer
Implementations
Sourceimpl<'a> Tokenizer<'a>
impl<'a> Tokenizer<'a>
Sourcepub fn skip_whitespace(&mut self)
pub fn skip_whitespace(&mut self)
Skip whitespace (space and tab only, not newlines)
Sourcepub fn read_until(&mut self, delim: u8) -> &'a [u8] ⓘ
pub fn read_until(&mut self, delim: u8) -> &'a [u8] ⓘ
Read until delimiter using SIMD search
Sourcepub fn read_until_any(&mut self, delims: &[u8]) -> &'a [u8] ⓘ
pub fn read_until_any(&mut self, delims: &[u8]) -> &'a [u8] ⓘ
Read until any of the delimiters
Sourcepub fn read_ident(&mut self) -> &'a [u8] ⓘ
pub fn read_ident(&mut self) -> &'a [u8] ⓘ
Read identifier (alphanumeric + underscore)
Sourcepub fn read_number(&mut self) -> Result<Token<'a>>
pub fn read_number(&mut self) -> Result<Token<'a>>
Read number (int or float)
Sourcepub fn read_string_vacuum(&mut self, next_is_number: bool) -> &'a [u8] ⓘ
pub fn read_string_vacuum(&mut self, next_is_number: bool) -> &'a [u8] ⓘ
Read string value using vacuum parsing Reads until the next expected type based on schema
Sourcepub fn read_string_validated(&mut self, next_is_number: bool) -> Result<&'a str>
pub fn read_string_validated(&mut self, next_is_number: bool) -> Result<&'a str>
Read string value with UTF-8 validation Returns an error if the string contains invalid UTF-8
Sourcepub fn read_ident_validated(&mut self) -> Result<&'a str>
pub fn read_ident_validated(&mut self) -> Result<&'a str>
Read identifier with UTF-8 validation
Sourcepub fn next_token(&mut self) -> Result<Token<'a>>
pub fn next_token(&mut self) -> Result<Token<'a>>
Get next token
Sourcepub fn peek_token(&self) -> Result<Token<'a>>
pub fn peek_token(&self) -> Result<Token<'a>>
Peek next token without consuming